@@ -1,5 +1,5 @@
 .onLoad <- function(lib, pkg) {
-#	library.dynam("robCompositions",pkg,lib)
+#library.dynam("robCompositions",pkg,lib)
 
 #	cat("\n ----------------------------------------------\n")	
 #    print(citation("robCompositions"))
@@ -24,4 +24,7 @@
 
 }
 
+.onUnload <- function(libpath)
+   library.dynam.unload("robCompositions",  libpath)
+
 robGUIenvir <- new.env()
\ No newline at end of file
